skip_value

Function skip_value 

pub fn skip_value(reader: &mut Bytes) -> Result<()>
Skips a value of any type in the senax binary format.

This is used for forward/backward compatibility when unknown fields/variants are encountered.

Errors

Returns an error if the value cannot be skipped (e.g., insufficient data).