Result

Type Alias Result 

pub type Result<T> = Result<T, EncoderError>;
The result type used throughout this crate for encode/decode operations.

All Encode and Decode trait methods return this type.

Aliased Type

pub enum Result<T> {
    Ok(T),
    Err(EncoderError),
}

Variants

1.0.0

Ok(T)

Contains the success value

1.0.0

Err(EncoderError)

Contains the error value