pub type Result<T> = Result<T, EncoderError>;Expand description
The result type used throughout this crate for encode/decode operations.
All Encode and Decode trait methods return this type.
Aliased Type
pub enum Result<T> {
Ok(T),
Err(EncoderError),
}